@@ -171,6 +171,8 @@ void FunctionsDialog::newClicked() {
 		if(replaced_item && (replaced_item == f || !CALCULATOR->hasFunction(replaced_item))) {
 			QModelIndexList list = sourceModel->match(sourceModel->index(0, 0), Qt::UserRole, QVariant::fromValue((void*) replaced_item), 1, Qt::MatchExactly);
 			if(!list.isEmpty()) sourceModel->removeRow(list[0].row());
+		} else if(replaced_item && !replaced_item->isActive()) {
+			ADD_INACTIVE_CATEGORY
 		}
 		selected_item = f;
 		QStandardItem *item = new QStandardItem(QString::fromStdString(f->title(true)));
@@ -204,6 +206,8 @@ void FunctionsDialog::editClicked() {
 		if(replaced_item && !CALCULATOR->hasFunction(replaced_item)) {
 			QModelIndexList list = sourceModel->match(sourceModel->index(0, 0), Qt::UserRole, QVariant::fromValue((void*) replaced_item), 1, Qt::MatchExactly);
 			if(!list.isEmpty()) sourceModel->removeRow(list[0].row());
+		} else if(replaced_item && !replaced_item->isActive()) {
+			ADD_INACTIVE_CATEGORY
 		}
 		QStandardItem *item = new QStandardItem(QString::fromStdString(f->title(true)));
 		item->setEditable(false);
@@ -266,7 +270,13 @@ void FunctionsDialog::deactivateClicked() {
 	MathFunction *f = (MathFunction*) index.data(Qt::UserRole).value<void*>();
 	if(f) {
 		f->setActive(!f->isActive());
-		functionsModel->invalidate();
+		QList<QTreeWidgetItem*> list = categoriesView->findItems(f->isActive() ? "All" : "Inactive", Qt::MatchExactly | Qt::MatchRecursive | Qt::MatchWrap, 1);
+		if(!list.isEmpty()) {
+			categoriesView->setCurrentItem(list[0], 0, QItemSelectionModel::SelectCurrent | QItemSelectionModel::Clear);
+		} else if(!f->isActive()) {
+				QStringList l; l << tr("Inactive"); l << "Inactive";
+				categoriesView->setCurrentItem(new QTreeWidgetItem(categoriesView, l), 0, QItemSelectionModel::SelectCurrent | QItemSelectionModel::Clear);
+		}
 		emit itemsChanged();
 	}
 }
