@@ -102,7 +102,8 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	statusDelayWidget = new QSpinBox(this);
 	statusDelayWidget->setRange(0, 10000);
 	statusDelayWidget->setSingleStep(250);
-	statusDelayWidget->setSuffix(" ms");
+	//: milliseconds
+	statusDelayWidget->setSuffix(" " + tr("ms"));
 	statusDelayWidget->setValue(settings->expression_status_delay); 
 	connect(statusDelayWidget, SIGNAL(valueChanged(int)), this, SLOT(statusDelayChanged(int)));
 	hbox->addWidget(statusDelayWidget);
@@ -125,6 +126,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->addItem(tr("Chain"), PARSING_MODE_CHAIN);
 	combo->addItem(tr("RPN"), PARSING_MODE_RPN);
 	combo->setCurrentIndex(combo->findData(settings->evalops.parse_options.parsing_mode));
+	parseCombo = combo;
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(parsingModeChanged(int)));
 	l2->addWidget(combo, r, 1); r++;
 	BOX_G(tr("Read precision"), settings->evalops.parse_options.read_precision != DONT_READ_PRECISION, readPrecisionToggled(bool));
@@ -142,10 +144,13 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	BOX(tr("Binary two's complement representation"), settings->printops.twos_complement, binTwosToggled(bool));
 	BOX(tr("Hexadecimal two's complement representation"), settings->printops.hexadecimal_twos_complement, hexTwosToggled(bool));
 	BOX(tr("Use lower case letters in non-decimal numbers"), settings->printops.lower_case_numbers, lowerCaseToggled(bool));
+	BOX(tr("Use dot as multiplication sign"), settings->printops.multiplication_sign != MULTIPLICATION_SIGN_X, multiplicationDotToggled(bool));
+	BOX(tr("Use Unicode division slash in output"), settings->printops.division_sign == DIVISION_SIGN_DIVISION_SLASH, divisionSlashToggled(bool));
 	BOX(tr("Spell out logical operators"), settings->printops.spell_out_logical_operators, spellOutToggled(bool));
 	BOX(tr("Use E-notation instead of 10^n"), settings->printops.lower_case_e, eToggled(bool));
 	BOX(tr("Use 'j' as imaginary unit"), CALCULATOR->getVariableById(VARIABLE_ID_I)->hasName("j") > 0, imaginaryJToggled(bool));
 	BOX(tr("Use comma as decimal separator"), CALCULATOR->getDecimalPoint() == COMMA, decimalCommaToggled(bool));
+	decimalCommaBox = box;
 	BOX(tr("Ignore comma in numbers"), settings->evalops.parse_options.comma_as_separator, ignoreCommaToggled(bool)); ignoreCommaBox = box;
 	BOX(tr("Ignore dots in numbers"), settings->evalops.parse_options.dot_as_separator, ignoreDotToggled(bool)); ignoreDotBox = box;
 	BOX(tr("Round halfway numbers to even"), settings->printops.round_halfway_to_even, roundEvenToggled(bool));
@@ -172,7 +177,7 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->addItem(tr("Lower"), INTERVAL_DISPLAY_LOWER);
 	combo->addItem(tr("Upper"), INTERVAL_DISPLAY_UPPER);
 	if(settings->adaptive_interval_display) combo->setCurrentIndex(0);
-	else combo->setCurrentIndex(combo->findData(settings->evalops.interval_calculation));
+	else combo->setCurrentIndex(combo->findData(settings->printops.interval_display));
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(intervalDisplayChanged(int)));
 	l2->addWidget(combo, r, 1); r++;
 	l2->addWidget(new QLabel(tr("Complex number form:"), this), r, 0);
@@ -223,10 +228,21 @@ PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent) {
 	combo->addItem(tr("Relative"), TEMPERATURE_CALCULATION_RELATIVE);
 	combo->addItem(tr("Hybrid"), TEMPERATURE_CALCULATION_HYBRID);
 	combo->setCurrentIndex(combo->findData(CALCULATOR->getTemperatureCalculationMode()));
+	tcCombo = combo;
 	l2->addWidget(combo, r, 1); r++;
 	connect(combo, SIGNAL(currentIndexChanged(int)), this, SLOT(temperatureCalculationChanged(int)));
 	box = new QCheckBox(tr("Exchange rates updates:"), this); box->setChecked(settings->auto_update_exchange_rates > 0); connect(box, SIGNAL(toggled(bool)), this, SLOT(exratesToggled(bool))); l2->addWidget(box, r, 0);
-	QSpinBox *spin = new QSpinBox(this); spin->setRange(1, 100); spin->setSuffix(" " + tr("days")); spin->setValue(settings->auto_update_exchange_rates <= 0 ? 7 : settings->auto_update_exchange_rates); spin->setEnabled(settings->auto_update_exchange_rates > 0); connect(spin, SIGNAL(valueChanged(int)), this, SLOT(exratesChanged(int))); l2->addWidget(spin, r, 1); exratesSpin = spin; r++;
+	int days = settings->auto_update_exchange_rates <= 0 ? 7 : settings->auto_update_exchange_rates;
+	QSpinBox *spin = new QSpinBox(this); spin->setRange(1, 100); spin->setValue(days); spin->setEnabled(settings->auto_update_exchange_rates > 0); connect(spin, SIGNAL(valueChanged(int)), this, SLOT(exratesChanged(int))); l2->addWidget(spin, r, 1); exratesSpin = spin; r++;
+	QString str = tr("%n day(s)", "", days);
+	int index = str.indexOf(QString::number(days));
+	if(index == 0) {
+		str = str.mid(index + QString::number(days).length());
+		if(str == " day(s)") str = (days == 1 ? " day" : " days");
+		exratesSpin->setSuffix(str);
+	} else {
+		exratesSpin->setPrefix(str.right(index));
+	}
 	l2->setRowStretch(r, 1);
 	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
 	topbox->addWidget(buttonBox);
@@ -271,6 +287,18 @@ void PreferencesDialog::lowerCaseToggled(bool b) {
 	settings->printops.lower_case_numbers = b;
 	emit resultDisplayUpdated();
 }
+void PreferencesDialog::multiplicationDotToggled(bool b) {
+	if(b) settings->printops.multiplication_sign = MULTIPLICATION_SIGN_ALTDOT;
+	else settings->printops.multiplication_sign = MULTIPLICATION_SIGN_X;
+	emit resultDisplayUpdated();
+	emit symbolsUpdated();
+}
+void PreferencesDialog::divisionSlashToggled(bool b) {
+	if(b) settings->printops.division_sign = DIVISION_SIGN_DIVISION_SLASH;
+	else settings->printops.division_sign = DIVISION_SIGN_SLASH;
+	emit resultDisplayUpdated();
+	emit symbolsUpdated();
+}
 void PreferencesDialog::spellOutToggled(bool b) {
 	settings->printops.spell_out_logical_operators = b;
 	emit resultDisplayUpdated();
@@ -328,6 +356,7 @@ void PreferencesDialog::colorizeToggled(bool b) {
 }
 void PreferencesDialog::parsingModeChanged(int i) {
 	settings->evalops.parse_options.parsing_mode = (ParsingMode) qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
+	settings->implicit_question_asked = (settings->evalops.parse_options.parsing_mode == PARSING_MODE_CONVENTIONAL || settings->evalops.parse_options.parsing_mode == PARSING_MODE_IMPLICIT_MULTIPLICATION_FIRST);
 	emit expressionFormatUpdated(false);
 }
 void PreferencesDialog::temperatureCalculationChanged(int i) {
@@ -340,6 +369,15 @@ void PreferencesDialog::exratesToggled(bool b) {
 }
 void PreferencesDialog::exratesChanged(int i) {
 	settings->auto_update_exchange_rates = i;
+	QString str = tr("%n day(s)", "", i);
+	int index = str.indexOf(QString::number(i));
+	if(index == 0) {
+		str = str.mid(index + QString::number(i).length());
+		if(str == " day(s)") str = (i == 1 ? " day" : " days");
+		exratesSpin->setSuffix(str);
+	} else {
+		exratesSpin->setPrefix(str.right(index));
+	}
 }
 void PreferencesDialog::binaryPrefixesToggled(bool b) {
 	CALCULATOR->useBinaryPrefixes(b ? 1 : 0);
@@ -523,3 +561,26 @@ void PreferencesDialog::replaceExpressionChanged(int i) {
 	settings->replace_expression = qobject_cast<QComboBox*>(sender())->itemData(i).toInt();
 }
 
+void PreferencesDialog::updateDot() {
+	decimalCommaBox->blockSignals(true);
+	ignoreCommaBox->blockSignals(true);
+	ignoreDotBox->blockSignals(true);
+	decimalCommaBox->setChecked(CALCULATOR->getDecimalPoint() == COMMA);
+	ignoreCommaBox->setChecked(settings->evalops.parse_options.comma_as_separator);
+	ignoreDotBox->setChecked(settings->evalops.parse_options.dot_as_separator);
+	decimalCommaBox->blockSignals(false);
+	ignoreCommaBox->blockSignals(false);
+	ignoreDotBox->blockSignals(false);
+	if(CALCULATOR->getDecimalPoint() == COMMA) ignoreCommaBox->hide();
+	if(CALCULATOR->getDecimalPoint() == DOT) ignoreDotBox->hide();
+}
+void PreferencesDialog::updateParsingMode() {
+	parseCombo->blockSignals(true);
+	parseCombo->setCurrentIndex(parseCombo->findData(settings->evalops.parse_options.parsing_mode));
+	parseCombo->blockSignals(false);
+}
+void PreferencesDialog::updateTemperatureCalculation() {
+	tcCombo->blockSignals(true);
+	tcCombo->setCurrentIndex(tcCombo->findData(CALCULATOR->getTemperatureCalculationMode()));
+	tcCombo->blockSignals(false);
+}
